@@ -1,5 +1,5 @@
 from commitizen.cli import main
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
