@@ -7,6 +7,8 @@ from commitizen import bump, git, config, out, factory
 NO_COMMITS_FOUND = 3
 NO_VERSION_SPECIFIED = 4
 NO_PATTERN_MAP = 7
+COMMIT_FAILED = 8
+TAG_FAILED = 9
 
 
 class Bump:
@@ -51,21 +53,25 @@ class Bump:
         files: list = self.parameters["files"]
         dry_run: bool = self.parameters["dry_run"]
 
+        is_yes: bool = self.arguments["yes"]
         prerelease: str = self.arguments["prerelease"]
         increment: Optional[str] = self.arguments["increment"]
         is_initial: bool = False
 
         # Check if reading the whole git tree up to HEAD is needed.
         if not git.tag_exist(current_tag_version):
-            out.info(f"Tag {current_tag_version} could not be found. ")
-            out.info(
-                (
-                    "Possible causes:\n"
-                    "- version in configuration is not the current version\n"
-                    "- tag_format is missing, check them using 'git tag --list'\n"
+            if is_yes:
+                is_initial = True
+            else:
+                out.info(f"Tag {current_tag_version} could not be found. ")
+                out.info(
+                    (
+                        "Possible causes:\n"
+                        "- version in configuration is not the current version\n"
+                        "- tag_format is missing, check them using 'git tag --list'\n"
+                    )
                 )
-            )
-            is_initial = questionary.confirm("Is this the first tag created?").ask()
+                is_initial = questionary.confirm("Is this the first tag created?").ask()
 
         commits = git.get_commits(current_tag_version, from_beginning=is_initial)
 
@@ -110,6 +116,12 @@ class Bump:
 
         config.set_key("version", new_version.public)
         bump.update_version_in_files(current_version, new_version.public, files)
-        git.commit(message, args="-a")
-        git.tag(new_tag_version)
+        c = git.commit(message, args="-a")
+        if c.err:
+            out.error(c.err)
+            raise SystemExit(COMMIT_FAILED)
+        c = git.tag(new_tag_version)
+        if c.err:
+            out.error(c.err)
+            raise SystemExit(TAG_FAILED)
         out.success("Done!")
